/*
*    AWS IoT Middleware Sink
*    Author: Eliot Landrum <eliot@filament.com>
*    Created on: 2016-09-09
*    Based on example in https://github.com/aws/aws-iot-device-sdk-js/blob/master/examples/device-example.js
*/

'use strict';
// require the AWS IoT Device SDK module
var awsiotDevice = require('aws-iot-device-sdk').device;

// the sink setup
const setup = (settings, eventListener) => {

    // The device module exports an MQTT instance, which will attempt
    // to connect to the AWS IoT endpoint configured in the arguments.

    var timeout;
    const minDelay = 250;

    // setup the device with the parameters provided
    var device = awsiotDevice({
      keyPath: settings.keyPath,
      certPath: settings.certPath,
      caPath: settings.caPath,
      clientId: settings.clientId,
      region: settings.region
    })

    // when an event comes in from a Tap, publish the event contents to
    // the "topic" that is set to the Tap hashname
    eventListener((eventName, event) => {
      device.publish(event.hashname,JSON.stringify(event));
    })
}

// setup the parameters required for calling this middleware
const cmd = module.exports = (commandTemplate) => commandTemplate(
    "AWSIOT",
    [
      ["-k,--keyPath <PrivateKeyPath>","Required: Private Key Path"],
      ["-ce,--certPath <keyPath>","Required: Certificate Path"],
      ["-ca,--caPath <keyPath>","Required: Root CA Certificate Path"],
      ["-ci,--clientId <UniqueClientIdentifier>","Required: the unique AWS IoT client identifier"],
      ["-r,--region <region>","Required: AWS Region"]
    ],
    setup
)
